==> haskell-attoparsec-0.13.0.1-8-armv7h.pkg.tar.xz: usr/share/haskell/haskell-attoparsec/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: attoparsec
version: 0.13.0.1
id: attoparsec-0.13.0.1-cc18275e376dae94cc21e54b8b072afd
key: attop_KGz8kXnHawX2yTRIBzGnQa
license: BSD3
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
stability: experimental
homepage: https://github.com/bos/attoparsec
synopsis: Fast combinator parsing for bytestrings and text
description:
    A fast parser combinator library, aimed particularly at dealing
    efficiently with network protocols and complicated text/binary
    file formats.
category: Text, Parsing
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
exposed-modules:
    Data.Attoparsec Data.Attoparsec.ByteString
    Data.Attoparsec.ByteString.Char8 Data.Attoparsec.ByteString.Lazy
    Data.Attoparsec.Char8 Data.Attoparsec.Combinator
    Data.Attoparsec.Internal Data.Attoparsec.Internal.Types
    Data.Attoparsec.Lazy Data.Attoparsec.Number Data.Attoparsec.Text
    Data.Attoparsec.Text.Lazy Data.Attoparsec.Types
    Data.Attoparsec.Zepto
hidden-modules: Data.Attoparsec.ByteString.Buffer
                Data.Attoparsec.ByteString.FastSet
                Data.Attoparsec.ByteString.Internal
                Data.Attoparsec.Internal.Fhthagn Data.Attoparsec.Text.Buffer
                Data.Attoparsec.Text.FastSet Data.Attoparsec.Text.Internal
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/attoparsec-0.13.0.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/attoparsec-0.13.0.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/attoparsec-0.13.0.1
hs-libraries: HSattoparsec-0.13.0.1-KGz8kXnHawX2yTRIBzGnQa
depends:
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    scientific-0.3.4.4-3faa9d36abc45b55aed128d427a02fce
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
haddock-interfaces: /usr/share/doc/haskell-attoparsec/html/attoparsec.haddock
haddock-html: /usr/share/doc/haskell-attoparsec/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-attoparsec-0.13.0.1-9-armv7h.pkg.tar.xz: usr/share/haskell/haskell-attoparsec/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: attoparsec
version: 0.13.0.1
id: attoparsec-0.13.0.1-c82a92403ed30683a5cb6228370c626c
key: attop_J9KpGVXXisl2SCx1ugNrAd
license: BSD3
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
stability: experimental
homepage: https://github.com/bos/attoparsec
synopsis: Fast combinator parsing for bytestrings and text
description:
    A fast parser combinator library, aimed particularly at dealing
    efficiently with network protocols and complicated text/binary
    file formats.
category: Text, Parsing
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
exposed-modules:
    Data.Attoparsec Data.Attoparsec.ByteString
    Data.Attoparsec.ByteString.Char8 Data.Attoparsec.ByteString.Lazy
    Data.Attoparsec.Char8 Data.Attoparsec.Combinator
    Data.Attoparsec.Internal Data.Attoparsec.Internal.Types
    Data.Attoparsec.Lazy Data.Attoparsec.Number Data.Attoparsec.Text
    Data.Attoparsec.Text.Lazy Data.Attoparsec.Types
    Data.Attoparsec.Zepto
hidden-modules: Data.Attoparsec.ByteString.Buffer
                Data.Attoparsec.ByteString.FastSet
                Data.Attoparsec.ByteString.Internal
                Data.Attoparsec.Internal.Fhthagn Data.Attoparsec.Text.Buffer
                Data.Attoparsec.Text.FastSet Data.Attoparsec.Text.Internal
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/attoparsec-0.13.0.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/attoparsec-0.13.0.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/attoparsec-0.13.0.1
hs-libraries: HSattoparsec-0.13.0.1-J9KpGVXXisl2SCx1ugNrAd
depends:
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    scientific-0.3.4.5-648b7dc78cf09ce28c222dfd7438d54f
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
haddock-interfaces: /usr/share/doc/haskell-attoparsec/html/attoparsec.haddock
haddock-html: /usr/share/doc/haskell-attoparsec/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
